@@ -2,6 +2,8 @@ import logging
 
 from django.contrib.auth.models import User
 
+from xauth.models import XauthAssociation
+
 logger = logging.getLogger('xauth.backends')
 
 class XauthBackend(object):
@@ -10,15 +12,14 @@ class XauthBackend(object):
     supports_inactive_user = True
 
     def authenticate(self, xauth_response):
-        service = xauth_response['service']
-        logger.debug('Authenticating user with %s xauth service' % service)
+        logger.debug('Authenticating user with %s xauth service' % xauth_response['service'])
+
         try:
-            module = __import__('xauth.service.%s.backend' % service, globals(), locals(), ['foo'])
-            auth_func = getattr(module, 'authenticate')
-        except (ImportError, AttributeError), ex:
-            logger.error('Could not import service authentication backend', exc_info=ex)
+            assoc = XauthAssociation.objects.get(identity=xauth_response['identity'])
+        except XauthAssociation.DoesNotExist:
+            return None
         else:
-            return auth_func(xauth_response)
+            return assoc.user
 
     def get_user(self, user_id):
         try:
